function render(_ref) {
  let text = _ref.text;

  var _ref2 = <Component text={text} />;

  return () => _ref2;
}
